#!/bin/sh
# -*- coding: utf-8 -*-
#
# Univention Lib
#  shell function for creating UMC operation and acl objects
#
# Copyright 2011-2020 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

. /usr/share/univention-lib/umc.sh

eval "$(ucr shell ldap/base)"

BIND_ARGS="$@"

ucs_school_policies_create () {
	# create default policies

	additional_policy="$1"

	for policyname in ucsschool-umc-teachers-default ucsschool-umc-admins-default default-umc-all $additional_policy ; do
		udm policies/umc create $BIND_ARGS --ignore_exists \
			--position "cn=UMC,cn=policies,$ldap_base" --set name="${policyname}"
		if [ $? != 0 ]; then exit 1; fi
	done
}

ucs_school_policies_append () {
	# append operation set to all policies

	operation_set="$1"; shift
	additional_policy="$1"
	for policyname in ucsschool-umc-teachers-default ucsschool-umc-admins-default default-umc-all $additional_policy ; do
		udm policies/umc modify $BIND_ARGS --ignore_exists \
			--dn "cn=${policyname},cn=UMC,cn=policies,$ldap_base" \
			--append "allow=cn=$operation_set,cn=operations,cn=UMC,cn=univention,$ldap_base"
		if [ $? != 0 ]; then exit 1; fi
	done
}
